==> zither-1.1.11.tar.gz: zither_prj/apollon/menu5.php <==
<?php
require("./total.inc");


session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }



echo "<HTML>";
echo "<HEAD>";
echo "<meta http-equiv='Content-Type' content='text/html; charset=EUC-JP'>";
echo "<TITLE>Zither server Administration tool 'Apollon'</TITLE>";

echo "<style type='text/css'>";
echo "<!--
a { text-decoration:none; }
a:hover { text-decoration:underline; }
a:hover { color:red; }

.example {
width: 100%;
max-width: 100px;
min-width: 90px;
}

-->";
echo "</style>";

echo "</HEAD>";




// Cname Bname List 
$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }

//  ƻ֥å̾ꥹȺ
$bname_count = 0;
$result = pg_query($conn, "select distinct(bname) from userblock;");
if(!$result){
   print("banem select , bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   while($bname_count < $num){
      $bname_data[$bname_count] = rtrim(pg_fetch_Result($result, $bname_count, bname));
      $result1=pg_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
      if(!$result1){
         print("bname , canem select , bud query\n");
         exit;
         }
      $num1 = pg_num_rows($result1);
      if($num1 > 0){
         $cname_data[$bname_count] = rtrim(pg_fetch_Result($result1, 0, cname));
         }
      $bname_count++;
      }
   }
else{
   print("NG ƻ֥å̵Ǥ \n");
   }
pg_free_result($result);
pg_free_result($result1);


$cname_count = 0;
$result=pg_query($conn,"select distinct(cname) from connection;");
if(!$result){
   print("canem select , bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   while($cname_count < $num){
      $xcname_data[$cname_count] = rtrim(pg_fetch_Result($result, $cname_count, cname));
      $cname_count++;
      }
   }
pg_free_result($result);
pg_Close($conn);
// Cname Bname List 








echo "<center>";
print("<BODY Link='#FF8C00' Vlink='#FF8C00' Alink='#FF8C00'  bgcolor='$my_bgcolor' >\n");

// ³饤ȸ

echo "<h2 id='error'>";
echo "</h2>";
echo "<TABLE border='0' bgcolor='FFA500' cellspacing='3' cellpadding='0' width=125>";
echo "<tr>";
echo "<td align=center>";
echo "<font color='ffffff' size=2>";
echo "<b>";
echo "饤ȸ";
echo "</b>";
echo "</font>";
echo "</td>";
echo "</tr>";
echo "</table>";


echo "<a href='./monitor_manu.php?QUE_DATA=KENSAKU3' target='top'>ιܤΥޥ˥奢</a>";
echo "<br>";


echo "<FORM METHOD=GET ACTION='connect.php' target='top'>";
echo "<TABLE border='0' bgcolor='FFEBCD' cellspacing='8' cellpadding='0' width=125>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻ륯饤";
echo "<select size=1 name=CNAME class='example'>";
echo "<option value=''>ʤ";
for($select_count = 0; $select_count < $cname_count; $select_count++){
   echo "<option value=$xcname_data[$select_count]>$xcname_data[$select_count]";
   }
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=CNAME_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "饤IP(LIKE)";
echo "<INPUT type='text' NAME=CIP class='example' value='%'>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=CIP_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "³СIP(LIKE)";
echo "<INPUT type='text' NAME=SERVER class='example' value='%'>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=SERVER_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "С(LIKE)";
echo "<INPUT type='text' NAME=VER class='example' value='%'>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=VER_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ֹ";
echo "<INPUT type='text' NAME=UNO class='example' value=''>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=UNO_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "";
echo "<select size=1 name=STAT>";
echo "<option value=>NON";
echo "<option value=FREE>FREE";
echo "<option value=ON>ON";
echo "<option value=OFF>OFF";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=STAT_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ơ";
echo "<select size=1 name=MODE>";
echo "<option value=>NON";
echo "<option value=START>START";
echo "<option value=STOP>STOP";
echo "<option value=RESTART>RESTART";
echo "<option value=KILL>KILL";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=MODE_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "<input type=submit value=''>";
echo "</font>";
echo "</td>";
echo "</tr>";


echo "</table>";
echo "</form>";


echo "<br>";


echo "</center>";

?>

</BODY>
</HTML>

==> zither-1.1.15.tar.gz: zither_prj/apollon/menu5.php <==
<?php
require("./total.inc");


session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }


echo "<HTML>";
echo "<HEAD>";
echo "<meta http-equiv='Content-Type' content='text/html; charset=EUC-JP'>";
echo "<TITLE>Zither server Administration tool 'Apollon'</TITLE>";

echo "<style type='text/css'>";
echo "<!--
a { text-decoration:none; }
a:hover { text-decoration:underline; }
a:hover { color:red; }

.example {
width: 100%;
max-width: 100px;
min-width: 90px;
}

-->";
echo "</style>";

echo "</HEAD>";




// Cname Bname List 
$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }

//  ƻ֥å̾ꥹȺ
$bname_count = 0;
$result = pg_query($conn, "select distinct(bname) from userblock;");
if(!$result){
   print("banem select , bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   while($bname_count < $num){
      $bname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result, $bname_count, bname));
      $result1=pg_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
      if(!$result1){
         print("bname , canem select , bud query\n");
         exit;
         }
      $num1 = pg_num_rows($result1);
      if($num1 > 0){
         $cname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result1, 0, cname));
         }
      $bname_count++;
      }
   }
else{
   print("NG ƻ֥å̵Ǥ \n");
   }
pg_free_result($result);
pg_free_result($result1);


$cname_count = 0;
$result=pg_query($conn,"select distinct(cname) from connection;");
if(!$result){
   print("canem select , bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   while($cname_count < $num){
      $xcname_data[$cname_count] = enco_rtrim(pg_fetch_Result($result, $cname_count, cname));
      $cname_count++;
      }
   }
pg_free_result($result);
pg_Close($conn);
// Cname Bname List 








echo "<center>";
print("<BODY Link='#FF8C00' Vlink='#FF8C00' Alink='#FF8C00'  bgcolor='$my_bgcolor' >\n");

// ³饤ȸ

echo "<h2 id='error'>";
echo "</h2>";
echo "<TABLE border='0' bgcolor='FFA500' cellspacing='3' cellpadding='0' width=125>";
echo "<tr>";
echo "<td align=center>";
echo "<font color='ffffff' size=2>";
echo "<b>";
echo "饤ȸ";
echo "</b>";
echo "</font>";
echo "</td>";
echo "</tr>";
echo "</table>";


echo "<a href='./monitor_manu.php?QUE_DATA=KENSAKU3' target='top'>ιܤΥޥ˥奢</a>";
echo "<br>";


echo "<FORM METHOD=GET ACTION='connect.php' target='top'>";
echo "<TABLE border='0' bgcolor='FFEBCD' cellspacing='8' cellpadding='0' width=125>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻ륯饤";
echo "<select size=1 name=CNAME class='example'>";
echo "<option value=''>ʤ";
for($select_count = 0; $select_count < $cname_count; $select_count++){
   echo "<option value=$xcname_data[$select_count]>$xcname_data[$select_count]";
   }
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=CNAME_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "饤IP(LIKE)";
echo "<INPUT type='text' NAME=CIP class='example' value='%'>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=CIP_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "³СIP(LIKE)";
echo "<INPUT type='text' NAME=SERVER class='example' value='%'>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=SERVER_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "С(LIKE)";
echo "<INPUT type='text' NAME=VER class='example' value='%'>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=VER_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ֹ";
echo "<INPUT type='text' NAME=UNO class='example' value=''>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=UNO_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "";
echo "<select size=1 name=STAT>";
echo "<option value=>NON";
echo "<option value=FREE>FREE";
echo "<option value=ON>ON";
echo "<option value=OFF>OFF";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=STAT_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ơ";
echo "<select size=1 name=MODE>";
echo "<option value=>NON";
echo "<option value=START>START";
echo "<option value=STOP>STOP";
echo "<option value=RESTART>RESTART";
echo "<option value=KILL>KILL";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=MODE_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "<input type=submit value=''>";
echo "</font>";
echo "</td>";
echo "</tr>";


echo "</table>";
echo "</form>";


echo "<br>";


echo "</center>";

?>

</BODY>
</HTML>
